@@ -1,4 +1,5 @@
 from flask import Flask
+from flask.globals import current_app
 from celery import Celery
 
 celery = Celery('infosystem')
@@ -15,3 +16,13 @@ def init_celery(app: Flask) -> Celery:
 
     celery.Task = ContextTask
     return celery
+
+
+def decide_on_run(fn):
+    def wrapper(*args):
+        should_use_worker = current_app.config['USE_WORKER']
+        if should_use_worker:
+            return fn.delay(*args)
+        else:
+            return fn(*args)
+    return wrapper
