@@ -1,4 +1,3 @@
-from sqlalchemy import orm
 from infosystem.database import db
 from sqlalchemy import UniqueConstraint
 from infosystem.common.subsystem import entity
@@ -6,13 +5,13 @@ from infosystem.common.subsystem import entity
 
 class Application(entity.Entity, db.Model):
 
+    DEFAULT = "default"
+
     attributes = ['name', 'description']
     attributes += entity.Entity.attributes
 
     name = db.Column(db.String(30), nullable=False)
     description = db.Column(db.String(1000), nullable=False)
-    capabilities = orm.relationship('Capability', backref=orm.backref(
-        'application_capability'))
 
     __table_args__ = (UniqueConstraint('name', name='application_name_uk'),)
 
