@@ -1,8 +1,9 @@
 import flask
-from typing import Optional
+from typing import List
 
 from infosystem.common.subsystem import controller
 from infosystem.common import exception
+from infosystem.common.input import InputResource, InputResourceUtils
 
 
 class Controller(controller.Controller):
@@ -10,18 +11,23 @@ class Controller(controller.Controller):
     def __init__(self, manager, resource_wrap, collection_wrap):
         super().__init__(manager, resource_wrap, collection_wrap)
 
-    def _get_application_id_from_request(self) -> Optional[str]:
-        data = flask.request.get_json()
-        return data.get('application_id', None)
+    def _get_resources(self, input_resources) -> List[InputResource]:
+        resources = []
+        for input_resource in input_resources:
+            endpoint = input_resource.get('endpoint')
+            methods = input_resource.get('methods', [])
+            resource = (endpoint, methods)
+            resources.append(resource)
+
+        return InputResourceUtils.parse_resources(resources)
 
     def create_policies(self, id: str):
+        data = flask.request.get_json()
         try:
-            application_id = self._get_application_id_from_request()
-            if not application_id:
-                raise exception.BadRequest()
+            resources = data.get('resources', [])
+            data['resources'] = self._get_resources(resources)
 
-            self.manager.create_policies(id=id,
-                                         application_id=application_id)
+            self.manager.create_policies(id=id, **data)
 
         except exception.InfoSystemException as exc:
             return flask.Response(response=exc.message,
